rdflib package
==============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   rdflib.extras
   rdflib.namespace
   rdflib.plugins
   rdflib.tools

Submodules
----------

rdflib.collection module
------------------------

.. automodule:: rdflib.collection
   :members:
   :undoc-members:
   :show-inheritance:

rdflib.compare module
---------------------

.. automodule:: rdflib.compare
   :members:
   :undoc-members:
   :show-inheritance:

rdflib.compat module
--------------------

.. automodule:: rdflib.compat
   :members:
   :undoc-members:
   :show-inheritance:

rdflib.container module
-----------------------

.. automodule:: rdflib.container
   :members:
   :undoc-members:
   :show-inheritance:

rdflib.events module
--------------------

.. automodule:: rdflib.events
   :members:
   :undoc-members:
   :show-inheritance:

rdflib.exceptions module
------------------------

.. automodule:: rdflib.exceptions
   :members:
   :undoc-members:
   :show-inheritance:

rdflib.graph module
-------------------

.. automodule:: rdflib.graph
   :members:
   :undoc-members:
   :show-inheritance:

rdflib.parser module
--------------------

.. automodule:: rdflib.parser
   :members:
   :undoc-members:
   :show-inheritance:

rdflib.paths module
-------------------

.. automodule:: rdflib.paths
   :members:
   :undoc-members:
   :show-inheritance:

rdflib.plugin module
--------------------

.. automodule:: rdflib.plugin
   :members:
   :undoc-members:
   :show-inheritance:

rdflib.query module
-------------------

.. automodule:: rdflib.query
   :members:
   :undoc-members:
   :show-inheritance:

rdflib.resource module
----------------------

.. automodule:: rdflib.resource
   :members:
   :undoc-members:
   :show-inheritance:

rdflib.serializer module
------------------------

.. automodule:: rdflib.serializer
   :members:
   :undoc-members:
   :show-inheritance:

rdflib.store module
-------------------

.. automodule:: rdflib.store
   :members:
   :undoc-members:
   :show-inheritance:

rdflib.term module
------------------

.. automodule:: rdflib.term
   :members:
   :undoc-members:
   :show-inheritance:

rdflib.util module
------------------

.. automodule:: rdflib.util
   :members:
   :undoc-members:
   :show-inheritance:

rdflib.void module
------------------

.. automodule:: rdflib.void
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: rdflib
   :members:
   :undoc-members:
   :show-inheritance:
